@@ -10,6 +10,7 @@ from distutils.version import LooseVersion
 from sphinx import config as sphinx_config
 from sphinx.locale import _
 from sphinx.util import i18n as sphinx_i18n
+from sphinx.util import tags as sphinx_tags
 
 logger = logging.getLogger(__name__)
 
@@ -104,9 +105,7 @@ class VersionInfo:
 
     def vpathto(self, other_version_name):
         if self.current_version_name == other_version_name:
-            return "{}.html".format(
-                posixpath.split(self.context["pagename"])[-1]
-            )
+            return "{}.html".format(posixpath.split(self.context["pagename"])[-1])
 
         # Find relative outputdir paths from common output root
         current_version = self.metadata[self.current_version_name]
@@ -116,25 +115,19 @@ class VersionInfo:
         other_outputroot = os.path.abspath(other_version["outputdir"])
         outputroot = os.path.commonpath((current_outputroot, other_outputroot))
 
-        current_outputroot = os.path.relpath(
-            current_outputroot, start=outputroot
-        )
+        current_outputroot = os.path.relpath(current_outputroot, start=outputroot)
         other_outputroot = os.path.relpath(other_outputroot, start=outputroot)
 
         # Ensure that we use POSIX separators in the path (for the HTML code)
         if os.sep != posixpath.sep:
-            current_outputroot = posixpath.join(
-                *os.path.split(current_outputroot)
-            )
+            current_outputroot = posixpath.join(*os.path.split(current_outputroot))
             other_outputroot = posixpath.join(*os.path.split(other_outputroot))
 
         # Find relative path to root of other_version's outputdir
         current_outputdir = posixpath.dirname(
             posixpath.join(current_outputroot, self.context["pagename"])
         )
-        other_outputdir = posixpath.relpath(
-            other_outputroot, start=current_outputdir
-        )
+        other_outputdir = posixpath.relpath(other_outputroot, start=current_outputdir)
 
         if not self.vhasdoc(other_version_name):
             return posixpath.join(other_outputdir, "index.html")
@@ -182,7 +175,7 @@ def config_inited(app, config):
     app.connect("html-page-context", html_page_context)
 
     # Restore config values
-    old_config = sphinx_config.Config.read(data["confdir"])
+    old_config = sphinx_config.Config.read(data["confdir"], tags=sphinx_tags.Tags())
     old_config.pre_init_values()
     old_config.init_values()
     config.version = data["version"]
@@ -204,18 +197,10 @@ def setup(app):
     app.add_config_value("smv_latest_version", "master", "html")
     app.add_config_value("smv_rename_latest_version", "", "html")
     app.add_config_value("smv_tag_whitelist", DEFAULT_TAG_WHITELIST, "html")
-    app.add_config_value(
-        "smv_branch_whitelist", DEFAULT_BRANCH_WHITELIST, "html"
-    )
-    app.add_config_value(
-        "smv_remote_whitelist", DEFAULT_REMOTE_WHITELIST, "html"
-    )
-    app.add_config_value(
-        "smv_released_pattern", DEFAULT_RELEASED_PATTERN, "html"
-    )
-    app.add_config_value(
-        "smv_outputdir_format", DEFAULT_OUTPUTDIR_FORMAT, "html"
-    )
+    app.add_config_value("smv_branch_whitelist", DEFAULT_BRANCH_WHITELIST, "html")
+    app.add_config_value("smv_remote_whitelist", DEFAULT_REMOTE_WHITELIST, "html")
+    app.add_config_value("smv_released_pattern", DEFAULT_RELEASED_PATTERN, "html")
+    app.add_config_value("smv_outputdir_format", DEFAULT_OUTPUTDIR_FORMAT, "html")
     app.connect("config-inited", config_inited)
 
     return {
